@@ -1,4 +1,4 @@
-# Copyright 2023-2025 Geoffrey R. Scheller
+# Copyright 2023-2026 Geoffrey R. Scheller
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,27 +14,29 @@
 
 """
 Class SplitEnds
-===============
+---------------
 
-**LIFO stacks safely sharing immutable data.**
+.. admonition:: LIFO stacks safely sharing immutable data.
 
-- each ``SplitEnd`` is a very simple stateful (mutable) LIFO stack
-- data can be either "extended" to or "snipped" off the "end" 
-- the "root" of a ``SplitEnd``
-  - it is fixed and cannot be removed from the ``SplitEnd``
-- different mutable split ends can safely share the same "tail"
-- each ``SplitEnd`` sees itself as a singularly linked list
-- bush-like datastructures can be formed using multiple ``SplitEnds``
-- the ``SplitEnd.split`` and ``len`` methods are O(1)
-- in boolean context returns true if the ``SplitEnd`` is not just its "root"
+    - each ``SplitEnd`` is a very simple stateful (mutable) LIFO stack
+    - data can be either "extended" to or "snipped" off the "end" 
+    - the "root" of a ``SplitEnd``
+
+      - it is fixed and cannot be removed from the ``SplitEnd``
+
+    - different mutable split ends can safely share the same "tail"
+    - each ``SplitEnd`` sees itself as a singularly linked list
+    - bush-like datastructures can be formed using multiple ``SplitEnds``
+    - the ``SplitEnd.split`` and ``len`` methods are O(1)
+    - in boolean context returns true if the ``SplitEnd`` is not just its "root"
 
 """
 
 from collections.abc import Callable, Iterator
-from pythonic_fp.iterables.folding import reduce_left, fold_left
 from typing import cast, Final, overload
-from pythonic_fp.queues.lifo import LIFOQueue
 from pythonic_fp.gadgets.sentinels.flavored import Sentinel
+from pythonic_fp.iterables.folding import reduce_left, fold_left
+from pythonic_fp.queues.lifo import LIFOQueue
 from .splitend_node import SENode
 
 __all__ = ['SplitEnd']
@@ -52,6 +54,7 @@ class SplitEnd[D]:
         """
         :param root_data: Irremovable initial data at bottom of stack.
         :param data: Removable data to be pushed onto splitend stack.
+
         """
         if root is _sentinel:
             if ds:
@@ -83,6 +86,7 @@ class SplitEnd[D]:
     def __bool__(self) -> bool:
         """
         :returns: ``True`` is ``SplitEnd`` is not just its root node.
+
         """
         return bool(self._end)
 
@@ -121,6 +125,7 @@ class SplitEnd[D]:
 
         :param num: Optional number of nodes to cut, default is entire stack.
         :returns: Tuple of data cut off from end.
+
         """
         if num is None or num > self._count:
             num = self._count
@@ -146,6 +151,7 @@ class SplitEnd[D]:
         extension.
 
         :param ds: data to extend the splitend
+
         """
         for d in ds:
             node = SENode(d, self._end)
@@ -155,12 +161,14 @@ class SplitEnd[D]:
         """Return the data at end (top) of SplitEnd without consuming it.
 
         :returns: The data at the end of the SplitEnd.
+
         """
         return self._end.data()
 
     def root(self) -> SENode[D]:
         """
         :returns: The root SENode node of the SplitEnd.
+
         """
         return self._root
 
@@ -172,12 +180,16 @@ class SplitEnd[D]:
             Two nodes are compatible root nodes if and only if
 
             - they are both actually root nodes
-              - that is their previous nodes are themselves
+
+              - which implies that their previous nodes are themselves
+
             - their data compare as equal
+
               - comparing by identity is too strong for some use cases
 
         :returns: New SplitEnd with the same data and the new ``root``.
         :raises ValueError: If new and original root nodes are not compatible.
+
         """
         if not root:
             msg = 'New root node is not a root node.'
@@ -197,6 +209,7 @@ class SplitEnd[D]:
         """Snip data off tip of SplitEnd. Just return data if tip is root.
 
         :returns: Data snipped off tip, just return root data if at root.
+
         """
         if self._count > 1:
             data, self._end, self._count = self._end.both() + (self._count - 1,)
@@ -209,6 +222,7 @@ class SplitEnd[D]:
         """Split the end and add more data.
 
         :returns: New instance, same data nodes plus additional ones on end.
+
         """
         se: SplitEnd[D] = SplitEnd(self._root.data())
         se._count, se._end, se._root = self._count, self._end, self._root
@@ -226,6 +240,7 @@ class SplitEnd[D]:
         :param f: Folding function, first argument is for the accumulator.
         :param init: Optional initial starting value for the fold.
         :returns: Reduced value folding from tip to root in natural LIFO order.
+
         """
         if init is None:
             return self._end.fold(f)  # type: ignore
@@ -242,6 +257,7 @@ class SplitEnd[D]:
         :param f: Folding function, first argument is for the accumulator.
         :param init: Optional initial starting value for the fold.
         :returns: Reduced value folding from root to tip.
+
         """
         if init is None:
             return cast(T, reduce_left(reversed(self), cast(Callable[[D, D], D], f)))
